# Copyright 2022 VMware, Inc. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

$ErrorActionPreference = 'Stop';
$releaseVersion = 'v1.2.0'
$packageName = 'tanzu-cli'
$packagePath = "${releaseVersion}"
$scriptsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$checksumType64 = 'sha256'
$tanzuExeName = ''

# Check if we are dealing with an ARM64 architecture
$os = Get-WmiObject -Class Win32_OperatingSystem
if ($os.OSArchitecture -like "*ARM*") {
    $url64 = "https://github.com/vmware-tanzu/tanzu-cli/releases/download/${releaseVersion}/tanzu-cli-windows-arm64-windows11.zip"
    $checksum64 = '07e5faec18ff96de51dce9b87427de855469fa7483e1afd2bb6d1ba41e1a2e57'
    $tanzuExeName = 'tanzu-cli-windows_arm64.exe'
} else {
    $url64 = "https://github.com/vmware-tanzu/tanzu-cli/releases/download/${releaseVersion}/tanzu-cli-windows-amd64.zip"
    $checksum64 = '8ba2b780a413de6c68d8e5de12dd91ae0a03fa39a3a0ee47d5216255f3b7e40c'
    $tanzuExeName = 'tanzu-cli-windows_amd64.exe'
}

$packageArgs = @{
    packageName    = $packageName
    unzipLocation  = $scriptsDir
    url64bit       = $url64

    softwareName   = 'tanzu-cli'

    checksum64     = $checksum64
    checksumType64 = $checksumType64
}

function Install-TanzuEnvironment {
    # The default shim normally created by Chocolatey in the bin directory does not forward interrupts to the CLI
    # Since the CLI needs to catch interrupts we prevent chocolatey from creating the shim, and instead
    # we copy the full CLI binary to the bin directory

    $binDirectory = Join-Path $env:ChocolateyInstall 'bin'
    $tanzuExePath = Join-Path $(Join-Path ${scriptsDir} ${packagePath}) $tanzuExeName

    $tanzuExe = Join-Path ${binDirectory} tanzu.exe

    Copy-Item "${tanzuExePath}" "${tanzuExe}"

    #Create .ignore file so chocolatey does not shim the Exe
    New-Item "${tanzuExePath}.ignore" -type file -force | Out-Null

    # Setup shell completion
    if (Test-Path -Path $PROFILE) {
        if (-not (Select-String -Path $PROFILE -Pattern "tanzu completion powershell" -Quiet)) {
            Add-Content $PROFILE ""
            Add-Content $PROFILE "# Tanzu shell completion"
            Add-Content $PROFILE "if (Get-Command 'tanzu' -ErrorAction SilentlyContinue) {"
            Add-Content $PROFILE "   tanzu completion powershell | Out-String | Invoke-Expression"
            Add-Content $PROFILE "}"

            Write-Host -ForegroundColor Green "Enabled shell completion for 'tanzu' in $PROFILE."
            Write-Host -ForegroundColor Green "You will need to restart your shell for this to take effect."
        }
    } else {
        Write-Warning "Unable to setup shell completion for future sessions for the Tanzu CLI because $PROFILE does not exist."
        Write-Warning "Please follow the instructions of 'tanzu completion -h' to know how to enable shell completion."
    }
}

# this is a built-in function, read https://docs.chocolatey.org/en-us/create/functions/install-chocolateyzippackage
Install-ChocolateyZipPackage @packageArgs

Install-TanzuEnvironment
